@@ -40,8 +40,7 @@ ModifyPrinter::ModifyPrinter(const QString &destName, bool isClass, QWidget *par
     connect(ui->descriptionLE, &QLineEdit::textChanged, this, &ModifyPrinter::textChanged);
     connect(ui->locationLE, &QLineEdit::textChanged, this, &ModifyPrinter::textChanged);
     connect(ui->connectionLE, &QLineEdit::textChanged, this, &ModifyPrinter::textChanged);
-    connect(ui->membersLV, static_cast<void(ClassListWidget::*)(bool)>(&ClassListWidget::changed),
-            this, &ModifyPrinter::modelChanged);
+    connect(ui->membersLV, &ClassListWidget::changed, this, &ModifyPrinter::modelChanged);
 }
 
 ModifyPrinter::~ModifyPrinter()
@@ -223,7 +222,7 @@ void ModifyPrinter::save()
                     setValues(printer);
                 }
             } else {
-                KMessageBox::detailedSorry(this,
+                KMessageBox::detailedError(this,
                                            m_isClass ? i18nc("@info", "Failed to configure class") :
                                                        i18nc("@info", "Failed to configure printer"),
                                            request->errorMsg(),
